import { Router } from "express"
import { PrismaClient } from "@prisma/client"

const router = Router()
const prisma = new PrismaClient()

router.get("/", async (req, res) => {
    const posts = await prisma.post.findMany({
        orderBy: [{ id: "desc" }],
        include: {
            Comment: { select: { id: true } },
        },
    })
    return res.status(200).send(posts)
})

router.get("/:id", async (req, res) => {
    const id = parseInt(req.params.id)

    if (!id) return res.status(400).send({ message: "Invalid ID." })

    try {
        const post = await prisma.post.findUnique({
            where: { id },
        })

        if(!post) return res.status(404).send({ message: "Post not found." })

        return res.status(200).send(post)
    } catch (error) {
        console.error(error)
    }
})

router.post("/", async (req, res) => {
    const { title, body } = req.body as { title: string; body: string }

    if (!title) {
        return res.status(400).send({ message: "Title must be included." })
    }

    try {
        const newPost = await prisma.post.create({ data: { title, body } })
        return res.status(201).send(newPost)
    } catch (error) {
        console.error(error)
    }
})

export default router
